vitals-package: vitals: Large Language Model Evaluation

vitals-packageR Documentation

vitals: Large Language Model Evaluation

Description

logo

A port of 'Inspect', a widely adopted 'Python' framework for large language model evaluation. Specifically aimed at 'ellmer' users who want to measure the effectiveness of their large language model-based products, the package supports prompt engineering, tool usage, multi-turn dialog, and model graded evaluations.

Author(s)

Maintainer: Simon Couch simon.couch@posit.co (ORCID)

Authors:

Other contributors:

See Also

Useful links:


vitals documentation built on Sept. 3, 2026, 1:06 a.m.